@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package YAML::PP::Dumper;
 
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use YAML::PP::Emitter;
 
@@ -21,7 +21,7 @@ sub new {
 sub emitter { return $_[0]->{emitter} }
 sub set_emitter { $_[0]->{emitter} = $_[1] }
 
-sub dump {
+sub dump_string {
     my ($self, @docs) = @_;
     $self->emitter->init;
     $self->emitter->document_start_event({ implicit => 1 });
@@ -61,7 +61,7 @@ sub dump_node {
                 $anchor = $num;
             }
             else {
-                $self->emitter->alias_event({ content => $anchor });
+                $self->emitter->alias_event({ value => $anchor });
                 return;
             }
 
@@ -85,7 +85,7 @@ sub dump_node {
     elsif (ref $node) {
         if (ref $node eq 'JSON::PP::Boolean' or ref $node eq 'boolean') {
             $self->emitter->scalar_event({
-                content => $node ? 'true' : 'false',
+                value => $node ? 'true' : 'false',
                 style => ':',
                 anchor => $anchor,
             });
@@ -95,7 +95,7 @@ sub dump_node {
         }
     }
     else {
-        $self->emitter->scalar_event({ content => $node });
+        $self->emitter->scalar_event({ value => $node });
     }
 }
 
