@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package YAML::PP::Emitter;
 
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use constant DEBUG => $ENV{YAML_PP_EMIT_DEBUG};
 
@@ -247,7 +247,7 @@ sub scalar_event {
     my $current_indent = $self->current_indent;
     my $indent = ' ' x $current_indent;
     my $props = '';
-    my $value = $info->{content};
+    my $value = $info->{value};
     my $anchor = $info->{anchor};
     my $tag = $info->{tag};
     if (defined $anchor) {
@@ -434,7 +434,7 @@ sub alias_event {
     my $current_indent = $self->current_indent;
     my $indent = ' ' x $current_indent;
 
-    my $alias = '*' . $info->{content};
+    my $alias = '*' . $info->{value};
 
     if ($stack->[-1] eq 'MAP') {
         $$yaml .= "$indent$alias :";
