@@ -3,10 +3,11 @@ use strict;
 use warnings;
 package YAML::PP::Loader;
 
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use YAML::PP::Parser;
 use YAML::PP::Constructor;
+use YAML::PP::Reader;
 
 sub new {
     my ($class, %args) = @_;
@@ -30,6 +31,18 @@ sub new {
 sub parser { return $_[0]->{parser} }
 sub constructor { return $_[0]->{constructor} }
 
+sub load_string {
+    my ($self, $yaml) = @_;
+    $self->parser->lexer->set_reader(YAML::PP::Reader->new);
+    $self->load($yaml);
+}
+
+sub load_file {
+    my ($self, $file) = @_;
+    $self->parser->lexer->set_reader(YAML::PP::Reader::File->new);
+    $self->load($file);
+}
+
 sub load {
     my ($self, $yaml) = @_;
     my $parser = $self->parser;
